@@ -7,7 +7,7 @@ package Spreadsheet::WriteExcel::OLEwriter;
 #
 # Used in conjunction with Spreadsheet::WriteExcel
 #
-# Copyright 2000-2004, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2005, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -24,7 +24,7 @@ use FileHandle;
 use vars qw($VERSION @ISA);
 @ISA = qw(Exporter);
 
-$VERSION = '2.01';
+$VERSION = '2.15';
 
 ###############################################################################
 #
@@ -322,7 +322,7 @@ sub _write_property_storage {
 
     #################  name         type   dir start size
     $self->_write_pps('Root Entry', 0x05,   1,   -2, 0x00);
-    $self->_write_pps('Book',       0x02,  -1, 0x00, $booksize);
+    $self->_write_pps('Workbook',   0x02,  -1, 0x00, $booksize);
     $self->_write_pps('',           0x00,  -1, 0x00, 0x0000);
     $self->_write_pps('',           0x00,  -1, 0x00, 0x0000);
 }
@@ -442,6 +442,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
- MM-MMIV, John McNamara.
+ MM-MMV, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
